@@ -1,22 +1,19 @@
+from toxopy import trials
 import json
 from numpy import mean, median
 
 
 def obtain_grand_m(json_file_loc):
 
-    #json_file_loc is the path to the json file with all individual avgs data
-    #output_dir is where you want to dump the .csv file to (optional)
+    # json_file_loc is the path to the json file with all individual avgs data
+    # output_dir is where you want to dump the .csv file to (optional)
 
     with open(json_file_loc) as json_file:
         data = json.load(json_file)
 
     var = ['distance', 'cat_distance', 'vel', 'acceleration', 'moving']
 
-    trials = [
-        'no treatment', 'cat alone (1)', 'first saline', 'cat alone (2)',
-        'first urine', 'cat alone (3)', 'second saline', 'cat alone (4)',
-        'second urine', 'cat alone (5)'
-    ]
+    tls = trials()
 
     dct = {}
 
@@ -27,7 +24,7 @@ def obtain_grand_m(json_file_loc):
     for p, n in zip(list(data['positive'].keys()),
                     list(data['negative'].keys())):
 
-        for t in trials:
+        for t in tls:
 
             for v, o in zip(var, range(0, 5)):
 
@@ -42,13 +39,10 @@ def obtain_grand_m(json_file_loc):
 
         print('infection_status,variable,mean,median', file=f)
 
-        for g in dct.keys():
+        for g in dct:
 
             for q in ['positive', 'negative']:
 
                 if g.startswith(q[0]):
 
-                    print(q + ',' + g[1:] + ',' + str(mean(dct[g])) + ',' +
-                          str(median(dct[g])),
-                          file=f)
-    f.close()
+                    print(f'{q},{g[1:]},{mean(dct[g])},{median(dct[g])}', file=f)
